@@ -46,8 +46,10 @@
 /* --------------------------------------------------------------------- */
 
 static l1_time_t last_time = 0; 
-static pthread_cond_t l1cond = PTHREAD_COND_INITIALIZER;
-static pthread_mutex_t l1mutex = PTHREAD_MUTEX_INITIALIZER;
+/*static  */
+pthread_cond_t l1cond = PTHREAD_COND_INITIALIZER;
+/*static */
+pthread_mutex_t l1mutex = PTHREAD_MUTEX_INITIALIZER;
 
 static struct l1rxslots l1rxslots[NUMRXSLOTS];
 static struct l1txslots l1txslots[NUMTXSLOTS];
@@ -317,6 +319,52 @@ unsigned long l1_fsk_wait_request(void)
 #endif /* DEBUG_MSG */
 	return id;
 }
+/* --------------------------------------------------------------------- */
+
+unsigned long l1_fsk_wait_tx_request(void)
+{
+	//is called by mode_(...) from l2 thread
+	/* experiment by dl4mge to make cw elbug quicker */
+	int i, idx, cnt = 0;
+	unsigned long id;
+	l1_time_t tm = 0;
+
+	if (pthread_mutex_lock(&l1mutex))
+		errstr(SEV_FATAL, "pthread_mutex_lock");
+	pthread_cleanup_push(fsk_wait_cleanup, NULL);
+	if (pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL))
+		errstr(SEV_FATAL, "pthread_setcancelstate");
+	for (;;) {
+		for (idx = -1, i = 0; i < NUMTXSLOTS; i++) {
+			if (l1txslots[i].state == l1ss_retired)
+				if (idx < 0 || (signed)(tm - l1txslots[i].tstart) > 0) {
+					tm = l1txslots[i].tstart;
+					idx = i;
+				}
+			cnt += (l1txslots[i].state != l1ss_unused);
+		}
+		if (idx >= 0) {
+			id = l1txslots[idx].id;
+			l1txslots[idx].state = l1ss_unused;
+			i = 0;
+			break;
+		}
+		if (cnt <= 0)
+			errprintf(SEV_FATAL, 
+			    "l1_wait_tx_request: no tx requests pending");
+		if (pthread_cond_wait(&l1cond, &l1mutex))
+			errstr(SEV_FATAL, "pthread_cond_wait");
+	}
+	pthread_cleanup_pop(0);
+	if (pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL))
+		errstr(SEV_FATAL, "pthread_setcancelstate");
+	if (pthread_mutex_unlock(&l1mutex))
+		errstr(SEV_FATAL, "pthread_mutex_unlock");
+#ifdef DEBUG_MSG
+	errprintf(SEV_INFO, "retiring id %lx  rx %d\n", id, i);
+#endif /* DEBUG_MSG */
+	return id;
+}
 
 /* --------------------------------------------------------------------- */
 
