@@ -65,10 +65,11 @@
 #include "main.h"
 #include "standby.h"
 #include "oss.h"
+#include "mt63hflink.h"
+#include "cw.h"
 #ifdef HAVE_ALSA_ASOUNDLIB_H
 #include "alsa.h"
 #endif /* HAVE_ALSA_ASOUNDLIB_H */
-#include "mt63hflink.h"
 
 /* --------------------------------------------------------------------- */
 
@@ -86,7 +87,7 @@ unsigned int standby_flags =
   STANDBY_FLAG_FREQ_ESTIMATION|STANDBY_FLAG_MONITOR_200|STANDBY_FLAG_MONITOR_300;
 unsigned int comm_perm = S_IRWXU|S_IRWXG|S_IRWXO;
 
-extern int brake;
+extern int brake, elbug_rts;
 pthread_t thr_l2;
 
 int fd_audio = -1, fd_mixer = -1, fd_ptt = -1;
@@ -132,13 +133,14 @@ void output_ptt(int ptt)
 {
 	int par = TIOCM_RTS;
 
-	if (fd_ptt < 0)
-		return;
+	if (elbug_rts)	return;
+	if (fd_ptt < 0)	return;
+
 	if (ioctl(fd_ptt, 
 	    ((ptt && !invert_ptt) || (!ptt && invert_ptt)) ? 
 	    TIOCMBIS : TIOCMBIC, &par)) {
-	    errstr(SEV_FATAL, "ioctl: TIOCMBI[CS]");
-	    errstr(SEV_FATAL, "serial port for ptt can not be opened!");
+	    errstr(SEV_WARNING, "ioctl: TIOCMBI[CS]");
+	    errstr(SEV_WARNING, "serial port for ptt can not be opened!");
 	    errstr(SEV_FATAL, 
 		"maybe you have to modify serial port in /etc/hf.conf !");
 	}
@@ -282,7 +284,7 @@ void l1_init()
 	if (OSS) {
 	    if (fdx) {
 		errprintf(SEV_INFO, 
-		    "creating threads for oss full duplex driver ...\n");
+		    "creating thread for oss full duplex driver ...\n");
 	    	if (nommap) {
 		    if (pthread_create(&thr_l1, &thr_attr, 
 			oss_nommap_fdx_driver, (char *)name_audio))
@@ -303,7 +305,7 @@ void l1_init()
 
 #ifdef HAVE_ALSA_ASOUNDLIB_H
 	if (ALSA) {
-	    errprintf(SEV_INFO, "creating threads for ALSA driver ...\n");
+	    errprintf(SEV_INFO, "creating thread for ALSA driver ...\n");
 	    if (pthread_create(&thr_l1, &thr_attr, alsa_fdx_driver, 
 			(char *)name_audio))
 		errstr(SEV_FATAL, "pthread_create");
@@ -317,7 +319,7 @@ void l1_init()
 	
 	if (OSS) {
 	    errprintf(SEV_INFO, 
-		"creating threads for oss half duplex driver ...\n");
+		"creating thread for oss half duplex driver ...\n");
 	    if (nommap) {
 		if (pthread_create(&thr_l1, &thr_attr, oss_nommap_hdx_driver, 
 		    (char *)name_audio))
@@ -345,11 +347,14 @@ void l1_input_samples(l1_time_t tstart, l1_time_t tinc,
 	    l1_mt63_input_samples(samples, nsamples);
 	    return;
 	}
-	l1_fsk_input_samples(tstart, tinc, samples, nsamples);
-	return;
-	
-	errprintf(SEV_FATAL, "hfkernel: sound.c: no rx mode specified.\n");
-	exit (1);
+	else if (modefamily == FSK) {
+	    l1_fsk_input_samples(tstart, tinc, samples, nsamples);
+	    return;
+	}
+	else	
+	errprintf(SEV_WARNING, "hfkernel: no rx mode-family specified.\n");
+        return;
+	//exit (1);
 }
 
 /* --------------------------------------------------------------------- */
@@ -362,11 +367,14 @@ int l1_output_samples(l1_time_t tstart, l1_time_t tinc,
 	    retval = l1_mt63_output_samples(tstart, tinc, samples, nsamples);
 	    return retval;
 	}
-	retval = l1_fsk_output_samples(tstart, tinc, samples, nsamples);
-	return retval;
-
-	errprintf(SEV_FATAL, "hfkernel: sound.c: no tx mode specified.\n");
-	exit (1);
+	else if (modefamily == FSK) {
+	    retval = l1_fsk_output_samples(tstart, tinc, samples, nsamples);
+	    return retval;
+	}
+	else 
+	errprintf(SEV_WARNING, "hfkernel: no tx mode-family specified.\n");
+	return 0;
+	//exit (1);
 }
 
 /* --------------------------------------------------------------------- */
@@ -413,7 +421,7 @@ static void start_threads(void)
 	    errstr(SEV_WARNING, "pthread_attr_setschedparam");
 #endif
 /* here a primitive test for implementing new modes... */
-//	if (pthread_create(&thr_l2, &thr_attr, mode_mt63_tx, NULL))
+//	if (pthread_create(&thr_l2, &thr_attr, mode_cw_tx, NULL))
 	if (pthread_create(&thr_l2, &thr_attr, mode_standby, NULL))
 	    errstr(SEV_FATAL, "pthread_create");
 #ifdef HAVE_SCHED_H
@@ -452,7 +460,7 @@ int main(int argc, char *argv[])
 		    break;
 
 		case 'c':
-		    name_comm = optarg;
+		    if (optarg != NULL) name_comm = optarg;
 		    break;
 
 		case 'p':
@@ -469,7 +477,6 @@ int main(int argc, char *argv[])
 
                 case 'k':
                     system ("killall hfkernel");
-                    exit;
 
                 case 'l':
                     logging = 1;
@@ -552,16 +559,17 @@ int main(int argc, char *argv[])
 			"                [-s <soundcard clock correction>] [-t <gettimeofday correction>]\n\n"
 			"  -2: standby: disable monitoring of 200baud signals\n"
 			"  -3: standby: disable monitoring of 300baud signals\n"
-			"  -a: audio device path (default: /dev/dsp)\n"
+			"  -a: audio device path (default for OSS: /dev/dsp)\n"
+			"      (for ALSA driver use -a plughw:0,0)\n"
 			"  -c: path of the communication socket (default: hfapp)\n"
 			"  -f: standby: disable frequency estimation\n"			
-			"  -h: force half duplex mode\n"			
+			"  -h: force half duplex mode (for OSS only!)\n"			
 			"  -i: invert PTT (default: PTT = positive signal)\n"
 			"  -k: stop hfkernel (this is also used by the start script hf)\n"
 			"  -l: logging (default: off)\n"			
 			"  -M: mixer device path (default: none)\n"
 			"  -m: CPU clock in MHz (exactly at kHz level)\n"
-			"  -n: no mmap() (which some cards/drivers can't) (experimental!)\n"			
+			"  -n: no mmap() (which some cards/drivers can't) (for OSS only!)\n"			
 			"  -p: path of the serial port to output PTT (default: none)\n"
 			"  -R: disable the use of the rdtsc instruction (Intel systems only)\n"
 			"  -r: access permissions of the communication socket (default: 0777 = rwxrwxrwx)\n"
@@ -583,5 +591,3 @@ int main(int argc, char *argv[])
 	exit(0);
 }
 
-/* --------------------------------------------------------------------- */
- 
\ No newline at end of file
