@@ -52,6 +52,7 @@
 #include "pactor.h"
 #include "amtor.h"
 #include "rtty.h"
+#include "cw.h"
 #include "mt63hflink.h"
 /*#include "byteorder.h"*/
 
@@ -87,9 +88,13 @@ static struct {
 
 /*
  *  to make mode group known
- *  for test at begin, switched to FSK
+ *  to prevent hangs at switching from MT63 to FSK, I hope..
  */
-int modefamily = 0;
+int modefamily;
+#define FSK 1
+#define MT63 2
+
+int beaconpause = 5;
 
 /* --------------------------------------------------------------------- */
 /*
@@ -293,11 +298,21 @@ void bufprintf(unsigned int which, const char *fmt, ...)
 	static struct sched_param schp;
 #endif /* NOREALTIME */
 	pthread_attr_t thr_attr;
+	static int crashblock = 0;
 
+	if(crashblock > 0) {
+	    bufprintf(HFAPP_MSG_DATA_STATUS, 
+		"start of new mode in progress.\n"
+		"-> no mode-changing commands accepted for now.");
+	    return;
+	}
+	crashblock = 1;
+	
 	if (pthread_cancel(thr_l2))
 		errstr(SEV_FATAL, "pthread_cancel");
 	if (pthread_join(thr_l2, NULL))
 		errstr(SEV_FATAL, "pthread_join");
+	modefamily = 0;
 	if (pthread_attr_init(&thr_attr))
 		errstr(SEV_FATAL, "pthread_attr_init");
 #ifndef NOREALTIME
@@ -308,10 +323,15 @@ void bufprintf(unsigned int which, const char *fmt, ...)
 	if (pthread_attr_setschedparam(&thr_attr, &schp))
 		errstr(SEV_FATAL, "pthread_attr_setschedparam");
 #endif /* NOREALTIME */
+        /* for sure, once more ... */
+        l1_fsk_clear_requests();
+	/* because cw elbug changes space to 0 and mark to cwtone... */
+	l1_set_fsk_params(FREQ_SPACE, FREQ_MARK);
 	if (pthread_create(&thr_l2, &thr_attr, routine, NULL))
 		errstr(SEV_FATAL, "pthread_create");
 	if (pthread_attr_destroy(&thr_attr))
 		errstr(SEV_WARNING, "pthread_attr_destroy");
+	crashblock = 0;
 }
 
 /* --------------------------------------------------------------------- */
@@ -325,6 +345,13 @@ static void process_msg(struct hfapp_msg *msg)
 	unsigned int u;
 
 	switch(type) {
+
+	case HFAPP_MSG_SET_GENERALPAR:
+		if (len < sizeof(msg->data.generalpar))
+			return;
+		beaconpause = msg->data.generalpar.beaconpause; 
+		return;
+
 	case HFAPP_MSG_REQ_SAMPLES:
 		if (len < sizeof(msg->data.u))
 			return;
@@ -361,18 +388,51 @@ static void process_msg(struct hfapp_msg *msg)
 			kbd_put(((*bp) & KBD_CHAR) | KBD_BIN);
 		return;
 
+
+
+	case HFAPP_MSG_SET_CWPAR:
+		if (len < sizeof(msg->data.cwpar))
+			return;
+		cw_set_params(
+		    ntohs(msg->data.cwpar.wpm), 
+		    ntohs(msg->data.cwpar.tone),
+		    msg->data.cwpar.farnsworth,
+		    msg->data.cwpar.dtr);
+		return;
+
+	case HFAPP_MSG_MODE_CW_RX:
+//		start_l2_thread(mode_cw_rx);
+		return;	
+		
+	case HFAPP_MSG_MODE_CW_TX:
+		start_l2_thread(mode_cw_tx);
+		return;	
+		
+	case HFAPP_MSG_CW_ELBUG_DIT:
+		lastcwmsg = type;
+		return;
+		
+	case HFAPP_MSG_CW_ELBUG_DAH:
+		lastcwmsg = type;
+		return;
+
+	case HFAPP_MSG_CW_ELBUG_TUNE:
+		lastcwmsg = type;
+		return;
+
+	case HFAPP_MSG_CW_ELBUG_PAUSE:
+		lastcwmsg = type;
+		return;
+
 	case HFAPP_MSG_START_STANDBY:
-		modefamily = FSK;
 		start_l2_thread(mode_standby);
 		return;
 
 	case HFAPP_MSG_START_PACTOR_STANDBY:
-		;
 		start_l2_thread(mode_pactor_standby);
 		return;
 
 	case HFAPP_MSG_START_PACTOR_ARQ:
-		;
 		start_l2_thread(mode_pactor_arq);
 		return;
 
@@ -438,7 +498,6 @@ static void process_msg(struct hfapp_msg *msg)
 		return;
 
 	case HFAPP_MSG_START_AMTOR_COLFEQ:
-		;
 		start_l2_thread(mode_amtor_colfec);
 		return;
 
@@ -552,18 +611,6 @@ static void process_msg(struct hfapp_msg *msg)
 		    htons(msg->data.mt63par.integration), 
 		    msg->data.mt63par.cwcall,
 		    msg->data.mt63par.doubleinterleave);
-//test 
-/*
-	    printf( "msg.c: \n"
-	    "now new mt63 params in mt63p:\n"
-	    "bandwidth %u Hz with %s interleave for tx, \n"
-	    "the time/frequency synchronizer integrates over %u symbols,\n"
-	    "at tx the call %s is sent in cw as background.\n",
-	    mt63p.bandwidth, 
-	    mt63p.doubleinterleave ? "DOUBLE (64)" : "SINGLE (32)",
-	    mt63p.integration, 
-	    mt63p.cwcall);
-*/
 		return;
 	default:
 		errprintf(SEV_WARNING, "unknown message type: %u length: %u\n",
