@@ -2,13 +2,18 @@
 #include "gui.h"
 #include "callbacks.h"
 
-// flags showing last transmit mode, for auto-transmit function
-// using the same defines as for the hfapp messages 
-int fbbtest = 0;
-int way = TX, beacon_file_prepared = 0, mailbox_prepared = 0;
 extern GtkWidget *textmain;
 extern guint squelch;
 
+int fbbtest = 0;
+int way = TX, beacon_file_prepared = 0, mailbox_prepared = 0;
+
+int elbugstate;
+#define PAUSE 0
+#define DIT 1
+#define DAH 2
+#define TUNE 3
+
 /* --- File menu ----------------------------------------------------- */ 
 
 void on_tx_file_activate(GtkMenuItem *menuitem, gpointer user_data)
@@ -18,6 +23,13 @@ void on_tx_file_activate(GtkMenuItem *menuitem, gpointer user_data)
 
 void on_beacon_file_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
+	if (beacon_was_on) {
+	    display_status
+		("Beacon was suspended during a connect, \n"
+		"you can not switch it on now manually.");
+	    beacon_on = 0;
+	    return;
+	}
 	if (beacon_on == 0) {
 	    if ((beacon_file_prepared == 0) && (fixbeacon == 0)) {
 		/* 
@@ -48,7 +60,7 @@ void on_beacon_file_activate(GtkMenuItem *menuitem, gpointer user_data)
 		 */
 		beacon_on = 1;
 		display_status
-		 ("Beacon already prepared, I switch it on.");
+		 ("Beacon text already prepared, I switch beacon on.");
 	    	 beacon_send(); 
 		 // must be started one time, from then on by loop in msg.c 
 		return;
@@ -125,8 +137,7 @@ gboolean on_spec_button_press_event(GtkWidget *widget, GdkEventButton *event, gp
  * but it is midnight almost. I stop for today. 19.jan 2005
  */
 		case 3:
-		    squelch = squelchvalue;
-		    display_status("set squelch to %d", squelch);
+		    goto set_squelch;
 		    break;
 	    }
 	return FALSE;
@@ -159,29 +170,18 @@ gboolean on_spec_button_press_event(GtkWidget *widget, GdkEventButton *event, gp
 	    	    }
 		    break;
 		case 3:
-		    squelch = squelchvalue;
-		    display_status("set squelch to %d", squelch);
+		    goto set_squelch;
 		    break;
 	    }
 	}
 //	printf("on_scope_button_press_event: x %g y %g  button 0x%04x\n", event->x, event->y, event->button);
 	return FALSE;
-}
 
-/* works n o t */
-void on_squelchruler_click_event
-    (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
-{
-	guint i = event->y;
-	
-	switch (event->button) {
-	    case 1:
-	    case 2:
-	    case 3:
-		display_status 
-    		    ("user-defined squelch %d", squelch);
-	    	squelch = i;
-	}
+set_squelch:
+	squelch = squelchvalue;
+	params.general.squelchpercent = 100 - (squelch * 100 / SPECTRUM_HEIGHT);
+	display_status("spec click: set squelch to %d", params.general.squelchpercent);
+    	return FALSE;
 }
 
 gboolean on_wspec_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data)
@@ -305,20 +305,19 @@ void on_mailbox_activate(GtkMenuItem *menuitem, gpointer user_data)
 		mailbox_on = 1;
 		autorx_on = 1; 
 //		gtk_text_set_editable (GTK_TEXT (textmain), TRUE);
-		display_status("You can test it by writing into the"
-		    " rx-window !");
+		display_status("You can test it: Write into rx-window !");
 		return;
 	}
 	if (mailbox_on == 1) {
 		mailbox_loggedout();
 		display_status
-		    ("Mailbox mode off. You can activate it again by <Alt> M.");
+		    ("Mailbox mode off. Restart by <Alt> M.");
 		// in case of mailbox-advertising in beacon...
 		if (beacon_on) {
 		    beacon_on = 0;
 		    display_status
 		    ("I also switched the beacon off."
-		    "(For sure, as it could have announced the mailbox.)"
+		    "(It might have announced the mailbox...)"
 		    "You can activate the beacon again by <Alt> B.");
 		}
 		mailbox_on = 0;
@@ -327,6 +326,21 @@ void on_mailbox_activate(GtkMenuItem *menuitem, gpointer user_data)
 	}
 }
 
+void on_cw_activate(GtkMenuItem *menuitem, gpointer user_data)
+{
+	struct hfapp_msg msg;
+
+	msg.hdr.err = htonl(ERR_NOERR);
+	msg.hdr.len = htonl(0);
+	msg.hdr.type = htonl(HFAPP_MSG_MODE_CW_TX);
+	msg_send(&msg);
+	display_status("CW ELBUG");
+	lastrxcmd = HFAPP_MSG_START_STANDBY;
+	lastrxmsg = 0;
+	lasttxcmd = HFAPP_MSG_MODE_CW_TX;
+	way = TX;
+}
+
 void on_standby_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
 	struct hfapp_msg msg;
@@ -505,9 +519,8 @@ void on_mt63_tx_activate(GtkMenuItem *menuitem, gpointer user_data)
 	usertx();
 }
 
-/* --- USER DATEN -------------------------------------------------- */ 
-/* --- ("brag" heit angeben)--------------------------------------- */ 
-
+/* --- USER DATA -------------------------------------------------- */ 
+/*
 void on_brag_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
 	  gtk_widget_show(wpersonal);
@@ -533,6 +546,7 @@ void on_brag_delete_button_clicked(GtkButton *button, gpointer user_data)
 	brag_delete();
 	brag_set();
 }
+*/
 
 /* --- Fixtexte  ---------------------------------------------------- */ 
 void on_Fix_button1_clicked(GtkButton *button, gpointer user_data)
@@ -646,8 +660,10 @@ gboolean on_rx_keypress_event(GtkWidget *widget, GdkEventKey *event, gpointer us
 //	display_status("on_text_keypress_event: 0x%x %c  state %u\n",
 //	event->keyval, (c >= ' ' && c <= 0x7f) ? c : '.', event->state);
 
-	if (event->state & ~(GDK_SHIFT_MASK | GDK_LOCK_MASK))
-		return FALSE;
+//	if (event->state & ~(GDK_SHIFT_MASK | GDK_LOCK_MASK))
+//		return FALSE;
+//	do't understand meaning of this, confuses !	
+
 	if (event->keyval == GDK_BackSpace) {
 		return TRUE;
 	}
@@ -706,29 +722,31 @@ gboolean on_rx_keyrelease_event(GtkWidget *widget, GdkEventKey *event, gpointer
 /* for transmit by keyboard */
 gboolean on_tx_keypress_event(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 {
-//	int c = event->keyval;
-//	printf("on_text_keypress_event: 0x%x %c  state %u\n",
-//	event->keyval, (c >= ' ' && c <= 0x7f) ? c : '.', event->state);
-//	display_status("tx keypress");
-/*
-	display_status("tx keypress: hex 0x%x is char %c",
-	    c, (c >= 32 && c < 128) ? c : '.');
-*/		
-	if (event->state & ~(GDK_SHIFT_MASK | GDK_LOCK_MASK))
-		return FALSE;
-	
-	if (event->keyval == GDK_BackSpace) {
+	int c = event->keyval;
+//	display_status("tx keypress: hex 0x%x is char %c",
+//	    c, (c >= 32 && c < 128) ? c : '.');
+		
+//	if (event->state & ~(GDK_SHIFT_MASK | GDK_LOCK_MASK)) {
+//              display_status("tx keypress: Shift or NumLock set. Do nothing.");
+//		return FALSE;
+//	}
+// don't understand meaning... if numlock on no 
+// autotx-on-write... why?
+
+	if (c == GDK_BackSpace) {
 		if( way == RX) autotx();
 		edit_backspace();
 		return TRUE;
 	}
-	if (event->keyval == GDK_Return) {
+	if (c == GDK_Return) {
 		if( way == RX) autotx();
 		edit_newline();
 		return TRUE;
 	}
-	if (event->keyval >= 32 && event->keyval < 128) {
-		if( way == RX) autotx();
+	if (c >= 32 && c < 128) {
+	    	if( way == RX) {
+		    autotx();
+		}
 		edit_addchar(event->keyval);
 		return TRUE;
 	}
@@ -743,6 +761,72 @@ gboolean on_tx_keyrelease_event(GtkWidget *widget, GdkEventKey *event, gpointer
 	return TRUE;
 }
 
+/* for cw elbug */
+gboolean on_textedit_button_press_event
+    (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+{
+	struct hfapp_msg msg;
+	msg.hdr.err = htonl(ERR_NOERR);
+	msg.hdr.len = htonl(0);
+
+	if (lasttxcmd != HFAPP_MSG_MODE_CW_TX) return FALSE;
+	
+	switch (event->button) {
+	case 3: /* dit */
+		msg.hdr.type = htonl(HFAPP_MSG_CW_ELBUG_DIT);
+		elbugstate = DIT;
+		display_status("cw dit");
+		break;
+	case 2: /* tune */
+		msg.hdr.type = htonl(HFAPP_MSG_CW_ELBUG_TUNE);
+		elbugstate = TUNE;
+		display_status("cw tune / tone ...");
+		break;
+ 	case 1: /* dah */
+		msg.hdr.type = htonl(HFAPP_MSG_CW_ELBUG_DAH);
+		elbugstate = DAH;
+		display_status("cw dah");
+		break;
+	}
+ 	msg_send(&msg);
+	return TRUE;
+}
+
+gboolean on_textedit_button_release_event
+    (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+{
+	int validpause = 0;
+	struct hfapp_msg msg;
+	msg.hdr.err = htonl(ERR_NOERR);
+	msg.hdr.len = htonl(0);
+	msg.hdr.type = htonl(HFAPP_MSG_CASE_UPPER);
+
+	switch (event->button) {
+	case 3: /* dit */
+		if (elbugstate == DIT) {
+		    validpause = 1;
+		}
+		break;
+	case 2: /* tune */
+		validpause = 1;
+		break;
+	case 1: /* dah */
+		if (elbugstate == DAH) {
+		    validpause = 1;
+		}
+		break;
+	}
+	/* not every release sends a message.
+	 * Imagine: i press dit, then dah just a ms before releasing dit,
+	 * then i release the dit key. This should have no effect.
+	 */	
+	if (validpause) {
+	    msg.hdr.type = htonl(HFAPP_MSG_CW_ELBUG_PAUSE);
+	    msg_send(&msg);
+	}
+	return TRUE;
+}
+
 gboolean on_wmain_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
 	finit();
