@@ -54,6 +54,7 @@ void on_gtor_arq1_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_amtor_arq_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_amtor_collective_fec_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_amtor_selective_fec_activate(GtkMenuItem *menuitem, gpointer user_data);
+void on_cw_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_rtty_receive_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_rtty_transmit_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_mt63_rx_activate(GtkMenuItem *menuitem, gpointer user_data);
@@ -116,6 +117,10 @@ void on_archivate_activate(GtkMenuItem *menuitem, gpointer user_data);
 void on_map1_activate(GtkMenuItem *menuitem, gpointer user_data);
 gboolean on_tx_keypress_event(GtkWidget *widget, GdkEventKey *event, gpointer user_data);
 gboolean on_tx_keyrelease_event(GtkWidget *widget, GdkEventKey *event, gpointer user_data);
+gboolean on_textedit_button_press_event
+    (GtkWidget *widget, GdkEventButton *event, gpointer user_data);
+gboolean on_textedit_button_release_event
+    (GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 gboolean on_rx_keypress_event(GtkWidget *widget, GdkEventKey *event, gpointer user_data);
 gboolean on_rx_keyrelease_event(GtkWidget *widget, GdkEventKey *event, gpointer user_data);
 gboolean on_wspec_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
