@@ -12,7 +12,6 @@ create_Wfixtext (void)
   GtkWidget *Wfixtext;
   GtkWidget *vbox_Fixtext;
   GtkWidget *Fixtext_frame2;
-  GtkWidget *scrolledwindow_fixtext;
   GtkWidget *notebook_Fixtext;
 
   GtkWidget *scrolledwindow1;
@@ -110,23 +109,10 @@ create_Wfixtext (void)
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (notebook_Fixtext);
   gtk_container_add (GTK_CONTAINER (Fixtext_frame2), notebook_Fixtext);
-  gtk_widget_set_usize (notebook_Fixtext, 400, 200);
+  gtk_widget_set_usize (notebook_Fixtext, 750, 325);
   gtk_notebook_set_tab_hborder (GTK_NOTEBOOK (notebook_Fixtext), 7);
   gtk_notebook_set_tab_vborder (GTK_NOTEBOOK (notebook_Fixtext), 3);
 
-  scrolledwindow_fixtext = gtk_scrolled_window_new (NULL, NULL);
-  gtk_widget_set_name (scrolledwindow_fixtext, "scrolledwindow_fixtext");
-  gtk_widget_ref (scrolledwindow_fixtext);
-  gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "scrolledwindow_fixtext", scrolledwindow_fixtext,
-                            (GtkDestroyNotify) gtk_widget_unref);
-  gtk_widget_show (scrolledwindow_fixtext);
-  gtk_container_add (GTK_CONTAINER (notebook_Fixtext), scrolledwindow_fixtext);
-  gtk_widget_set_usize (scrolledwindow_fixtext, 400, 200);
-  gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow_fixtext), 3);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow_fixtext), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  
-  
-
 /* - Fixtext  1 ----------------------------------------------------*/
     
   scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
@@ -157,7 +143,7 @@ create_Wfixtext (void)
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label1", label1,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (label1);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 1), label1);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 0), label1);
 
 /* - Fixtext  2 ----------------------------------------------------*/
 
@@ -185,7 +171,7 @@ create_Wfixtext (void)
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label2", label2,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (label2);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 2), label2);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 1), label2);
 
 
 /* - Fixtext 3 ----------------------------------------------------*/
@@ -214,7 +200,7 @@ create_Wfixtext (void)
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label3", label3,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (label3);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 3), label3);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 2), label3);
 
 /* - Fixtext  4 ----------------------------------------------------*/
   
@@ -242,7 +228,7 @@ create_Wfixtext (void)
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label4", label4,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (label4);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 4), label4);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 3), label4);
 
 /* - Fixtext  5 ----------------------------------------------------*/  
   
@@ -270,7 +256,7 @@ create_Wfixtext (void)
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label5", label5,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (label5);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 5), label5);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 4), label5);
 
 /* - Fixtext  6 ----------------------------------------------------*/  
   
@@ -298,7 +284,7 @@ create_Wfixtext (void)
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label6", label6,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (label6);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 6), label6);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 5), label6);
 
 /* - Fixtext 7 ------------------------------------------------------*/  
   
@@ -326,7 +312,7 @@ create_Wfixtext (void)
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label7", label7,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (label7);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 7), label7);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 6), label7);
 
 /* - Fixtext  8 ----------------------------------------------------*/  
   
@@ -354,7 +340,7 @@ create_Wfixtext (void)
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label8", label8,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (label8);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 8), label8);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 7), label8);
 
 /* - Fixtext 9 ------------------------------------------------------*/  
  
@@ -383,7 +369,7 @@ create_Wfixtext (void)
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label9", label9,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (label9);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 9), label9);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 8), label9);
 
 /* - Fixtext 10 ----------------------------------------------------*/  
   
@@ -411,7 +397,7 @@ create_Wfixtext (void)
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label10", label10,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (label10);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 10), label10);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 9), label10);
 
 /* - Fixtext 11 ----------------------------------------------------*/  
 
@@ -439,7 +425,7 @@ create_Wfixtext (void)
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label11", label11,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (label11);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 11), label11);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 10), label11);
 
 /* - Fixtext 12 ----------------------------------------------------*/  
   
@@ -467,7 +453,7 @@ create_Wfixtext (void)
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label12", label12,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (label12);
-  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 12), label12);
+  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_Fixtext), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_Fixtext), 11), label12);
 
 /* - Fixtexte Ende ----------------------------------------------------*/  
   
