@@ -46,7 +46,7 @@ create_wabout (void)
   gtk_widget_show (label29);
   gtk_box_pack_start (GTK_BOX (vbox5), label29, TRUE, TRUE, 3);
 
-  label30 = gtk_label_new (_("(C) 1999 Thomas Sailer, HB9JNX/AE4WA,\nwhith a little help by\nRalf-Axel Krystof, DF3JRK (df3jrk@gmx.de)\nGnther Montag, DL4MGE (dl4mge@darc.de) "));
+  label30 = gtk_label_new (_("(C) 1999 Thomas Sailer, HB9JNX/AE4WA,\nwhith a little help by\nRalf-Axel Krystof, DF3JRK (df3jrk@gmx.de)\nGünther Montag, DL4MGE (dl4mge@darc.de) "));
   gtk_widget_set_name (label30, "label30");
   gtk_widget_ref (label30);
   gtk_object_set_data_full (GTK_OBJECT (wabout), "label30", label30,
@@ -667,11 +667,11 @@ create_whilfe (void)
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (text_help_10);
   gtk_container_add (GTK_CONTAINER (scrw_help_10), text_help_10);
-  gtk_tooltips_set_tip (tooltips, text_help_10, _("Left Side English \nRight German"), NULL);
+//  gtk_tooltips_set_tip (tooltips, text_help_10, _("Left Side English \nRight German"), NULL);
   gtk_text_set_editable (GTK_TEXT (text_help_10), FALSE);
-  textinsert("/usr/share/hf/TODO", GTK_TEXT(text_help_10));
+//  textinsert("/usr/share/hf/TODO", GTK_TEXT(text_help_10));
 
-  label_help_10 = gtk_label_new (_("TODO"));
+  label_help_10 = gtk_label_new (_(""));
   gtk_widget_set_name (label_help_10, "label_help_10");
   gtk_widget_ref (label_help_10);
   gtk_object_set_data_full (GTK_OBJECT (whilfe), "label_help_10", label_help_10,
