@@ -130,16 +130,12 @@ void errprintf(int severity, const char *fmt, ...);
 void errstr(int severity, const char *st);
 extern void display_status(const char *fmt, ...);
 //int cb_canvas(FL_OBJECT *ob, Window win, int w, int h, XEvent *ev, void *d);
+void param_set_defaults(void);
 void param_get(void);
 void param_set(void);
 void param_kernel(void);
 void param_read();
 void param_store(void);
-void brag_get();
-void brag_set();
-void brag_delete();
-void brag_read();
-void brag_store();
 void timequery();
 
 void init(void);
@@ -153,7 +149,6 @@ GtkWidget *wmain;
 GtkWidget *wabout;
 GtkWidget *whilfe; 		/* HILFEDATEI */
 GtkWidget *Wfixtext;		/* FIXTEXTE */
-GtkWidget *wpersonal; 		/* USER DATEN */
 GtkWidget *Wsearchlogentr;	/* LOGBUCH DURCHSUCHEN */
 GtkWidget *wlistalllog; 	/* LISTE ALLE LOGBUCH EINTRAEGE */
 GtkWidget *wqsoeditor; 		/* ZEIGE LOGBUCH EINTRAEGE */
@@ -162,10 +157,33 @@ GtkWidget *wmap; 		/* WELTKARTE */
 GtkWidget *wmonitor;
 
 struct par {
+	struct {
+		unsigned char call[16];
+		unsigned char op[128];
+	        unsigned char qth[128];
+		unsigned char loc[128];
+		unsigned char rig[128];
+		unsigned char pwr[128];
+		unsigned char ant[128];
+		unsigned char www[128];
+	} brag;
+
+	struct {
+		unsigned int beaconpause;
+		unsigned int squelchpercent;
+	} general;
+
 	struct {
 		unsigned int freq[2];
 	} fsk;
 
+	struct {
+		unsigned int wpm;
+		unsigned int tone;
+		unsigned int farnsworth;
+		unsigned int dtr;
+	} cw;
+
 	struct {
 		unsigned int baud;
 		unsigned int rxinvert;
@@ -182,6 +200,13 @@ struct par {
 		unsigned int txinvert;
 	} amtor;
 
+	struct {
+		unsigned char destcall[10];
+		unsigned char mycall[10];
+		unsigned int txdelay;
+		unsigned int retry;
+	} gtor;
+
 	struct {
 		unsigned char destcall[8];
 		unsigned char mycall[8];
@@ -191,39 +216,25 @@ struct par {
 		unsigned int crcpreset[4];
 	} pactor;
 
-	struct {
-		unsigned char destcall[10];
-		unsigned char mycall[10];
-		unsigned int txdelay;
-		unsigned int retry;
-	} gtor;
-	
 	struct {
 	        unsigned int bandwidth;
 	        unsigned int integration;
 	        unsigned char cwcall[10];
 	        unsigned int doubleinterleave;
 	} mt63;
+	
+	struct {
+		char host[32];
+		unsigned int port;
+	} mailbox;
+
 };
 extern struct par params;
 
-struct personaledit {
-	unsigned char call[16];
-	unsigned char op[128];
-	unsigned char qth[128];
-	unsigned char loc[128];
-	unsigned char rig[128];
-	unsigned char pwr[128];
-	unsigned char ant[128];
-	unsigned char www[128];
-};
-extern struct personaledit brag;
 extern const char* fixmagic;
 extern int scope_on, mon_on, log_on, params_on, brag_on, fix_on;
 extern int rxfile_ready;
 extern char gmt[32];
-extern char* mailbox_host;
-extern int mailbox_port;
 extern GdkFont *radiofont;
 
 #endif /* _HFT_H */
