@@ -41,7 +41,6 @@
 
 /* --------------------------------------------------------------------- */
 
-#define BEACONPAUSE 7 // pause between beacon transmissions, 
 #define MAILBOXPAUSE 1 // pause between mailbox rx and tx,
 		      // the unit is Keepalive-message-intervals
 int beacon_pause = 0;
@@ -160,8 +159,8 @@ static void process_msg(struct hfapp_msg *msg)
  	    if (beacon_on == 1 && beacon_pause == 1) {	
  		beacon_wait_count++ ;
 		display_status("beacon countdown: %d", 
-		    BEACONPAUSE - beacon_wait_count);
-		if (beacon_wait_count >= BEACONPAUSE) {
+		    ((params.general.beaconpause + 5) / 5) - beacon_wait_count);
+		if (beacon_wait_count >= ((params.general.beaconpause + 5) / 5)) {
 //		    display_status
 //		    ("beacon countdown from %d to 0, will transmit beacon.", 
 //		    beacon_wait_count);
@@ -425,6 +424,15 @@ static void process_msg(struct hfapp_msg *msg)
 		display_status("GTOR SPEED 300");
 		arq = 1;
 		return;
+
+	case HFAPP_MSG_STATE_CW_TX:
+//		errprintf(SEV_INFO, "RTTY: Start Transmit  Error: %d\n", err);
+		arq = 0;
+		lasttxmsg = HFAPP_MSG_STATE_CW_TX;
+		EOF_count = 0;
+		qrt_pending = 0;
+		way = TX;
+		return;
 		
 	case HFAPP_MSG_STATE_RTTY_TX:
 //		errprintf(SEV_INFO, "RTTY: Start Transmit  Error: %d\n", err);
@@ -474,18 +482,47 @@ void msg_process(int fd)
 	int i;
 	unsigned char *bp;
 	unsigned int truelen;
-
+	static int read_check_count = 0;
+	int read_check_count_max = 1000;
+	
 	i = read(fd, rxbuf+rxbuf_size, sizeof(rxbuf)-rxbuf_size);
 	if (i < 0) {
-		if (errno != EAGAIN)
+		if (errno == EAGAIN) {
+		    display_status("error in reading message from hfkernel. Trying again...");
+		    read_check_count++;
+		    if (read_check_count > read_check_count_max) {
+			display_status
+			    ("error count is %d in reading message from hfkernel. Giving up.", 
+			    read_check_count);
 			errstr(SEV_FATAL, "read");
+	    	    }
+		    return;
+		}
+		if (errno != EAGAIN) {
+		    display_status("error in reading message from hfkernel. Giving up.");
+			errstr(SEV_FATAL, "read");
+		    return;
+		}
+	}
+	if (i == 0) {
+		read_check_count++;
+		if (read_check_count > read_check_count_max) {
+		    display_status
+		        ("reading message from hfkernel: %d zero-reads. Giving up.", 
+			    read_check_count);
+			errstr(SEV_FATAL, "hfterm: Did hfkernel die? exiting zero-read loop");
+	    	    }
 		return;
 	}
+	
+	read_check_count = 0;
 	rxbuf_size += i;
 	msg = (struct hfapp_msg *)(bp = rxbuf);
 	while (rxbuf_size >= sizeof(msg->hdr)) {
-		if (!HFAPP_MSG_ALIGNED(msg))
-			errprintf(SEV_FATAL, "msg_process: buffer not aligned\n");
+		if (!HFAPP_MSG_ALIGNED(msg)) {
+		    display_status("error in reading message from hfkernel: Buffer not aligned.");
+		    errprintf(SEV_FATAL, "msg_process: buffer not aligned\n");
+		}
 		truelen = HFAPP_MSG_ALIGN(sizeof(msg->hdr)+ntohl(msg->hdr.len));
 		if (truelen > rxbuf_size)
 			break;
@@ -493,8 +530,10 @@ void msg_process(int fd)
 		rxbuf_size -= truelen;
 		msg = (struct hfapp_msg *)(bp += truelen);
 	}
-	if (rxbuf_size >= sizeof(rxbuf))
-		errprintf(SEV_FATAL, "incoming message size too big\n");
+	if (rxbuf_size >= sizeof(rxbuf)) {
+	    display_status("error in reading message from hfkernel; Too big.");
+	    errprintf(SEV_FATAL, "incoming message size too big\n");
+	}
 	memmove(rxbuf, bp, rxbuf_size);
 }
 
