@@ -48,21 +48,34 @@ char specialfile[256], rxfilehead[256], rxfilefoot[256];
 char beaconbuffer[MAXKEY], keytext[MAXKEY];
 const char *fixmagic = 
 "	* * * * * * *	YOUR MAGIC KEYS: 	* * * * * * * \n"
-"[B] will transmit the text as BEACON. (Stop it with <Alt>b.)\n"
+"[B]	will transmit the text as BEACON. (Stop it with <Alt>b.)\n"
 "[MYCALL] [OP] [QTH] [LOC] [RIG] [PWR] [ANT] [WWW]\n"
-"will be replaced by your entries from 'Personal Edit'.\n"
+"	will be replaced by your entries from 'Personal Edit'.\n"
+"[AMYCALL] (Amtor), \n"
+"	is your own Amtor short-call, taken from 'Parameters'.\n"
 "[TIME]	will print a timestamp.\n"
 "[ACALL] (Amtor), [PCALL] = [CALL] (Pactor + RTTY), [GCALL] (Gtor)\n"
-"is your QSO-Partner's call, taken from 'Parameters'.\n"
-"[AMYCALL] (Amtor), [PMYCALL] = [CALL] (Pactor + RTTY), [GMYCALL] (Gtor)\n"
-"is your own call, taken from 'Parameters'.\n"
+"	is your QSO-Partner's call, taken from 'Parameters'.\n"
 "[LTIME] [LCALL] [LNAME] [LQTH] [LRSTIN] [LRSTOUT] [LNOTES] [LMODE] [LBAND]\n"
-"will be replaced by the corresponding fielod of last log entry.\n"
+"will be replaced by the corresponding field of your last log entry.\n"
 "You can use 'Strg-X, Strg-C, Strg-V to cut, copy and insert.\n"
-"To use the fixtexts, press Shift-F<number> or click the right buttons.\n"
-"* * * *  Have a lot of fun!  * * * * ";
+"To use the fixtexts, press <Shift-F><number> or click the right buttons.\n"
+"		* * * *  Have a lot of fun!  * * * * ";
 FILE *rxfile;
 
+/*
+[PMYCALL] = [CALL] (Pactor + RTTY), [GMYCALL] (Gtor)
+*/
+
+/* --------------------------------------------------------------- */
+
+void wait(int us) {
+    struct timeval tv;
+    tv.tv_sec = 0;
+    tv.tv_usec = us;
+    select (0, NULL, NULL, NULL, &tv);
+}
+
 /* --------------------------------------------------------------- */
 
 void transmit(const char *fmt, ... )
@@ -170,7 +183,7 @@ void parse(char* magic, char* bragitem)
 	  strcat(a, c + strlen(magic));
 //	  display_status( "\n\na nach 2. Teil\n%s", a);
 	  strcpy(keytext, a);
-	  printf("\nkeytext:\n%s", keytext);
+//	  printf("\nkeytext:\n%s", keytext);
 	}
     }
     return;
@@ -207,14 +220,14 @@ void fixtext_send(int fixnr)
 	  parse("[AMYCALL]", params.amtor.mycall);
           parse("[GCALL]", params.gtor.destcall);
 	  parse("[GMYCALL]", params.gtor.mycall);
-          parse("[MYCALL]", brag.call);
-          parse("[OP]", brag.op);
-          parse("[QTH]", brag.qth);
-          parse("[LOC]", brag.loc);
-          parse("[RIG]", brag.rig);
-          parse("[PWR]", brag.pwr);
-          parse("[ANT]", brag.ant);
-          parse("[WWW]", brag.www);
+          parse("[MYCALL]", params.brag.call);
+          parse("[OP]", params.brag.op);
+          parse("[QTH]", params.brag.qth);
+          parse("[LOC]", params.brag.loc);
+          parse("[RIG]", params.brag.rig);
+          parse("[PWR]", params.brag.pwr);
+          parse("[ANT]", params.brag.ant);
+          parse("[WWW]", params.brag.www);
           parse("[TIME]", gmt);
           if (lb.logsize != 0) {
           	parse ("[LTIME]", lb.line[lb.logsize].time);
@@ -370,7 +383,7 @@ void file_send()
 /* --------------------------------------------------------------- */
 
 void beacon_suspend() {
-	if (beacon_on) {
+	if (beacon_on == 1) {
 	    beacon_on = 0;
 	    beacon_was_on = 1;
 	    display_status 
@@ -381,7 +394,7 @@ void beacon_suspend() {
 /* --------------------------------------------------------------- */
 
 void beacon_restore() {
-	if (beacon_was_on) {
+	if (beacon_was_on == 1) {
 	    beacon_on = 1;
 	    beacon_was_on = 0;
 	    display_status 
@@ -452,6 +465,20 @@ void beacon_send() {
 	int l;
 	char v = 0;
 
+    /* 	bugtracking, 
+	beacon_suspend() while mailbox connect did not work */
+	if (beacon_on == 0) {
+	    display_status("wrong call of beacon_send(),\n"
+		"beacon off at the moment");
+	    return;
+	}
+	if (beacon_was_on == 1) {
+	    display_status("wrong call of beacon_send(),\n"
+		"beacon is suspended off at the moment");
+	    beacon_on = 0;
+	    return;
+	}
+	
 	if (fixbeacon) {
 	// a fixtext with the [B] magic key is already chosen as beacon text
 	    autorx_on = 1;
@@ -472,8 +499,9 @@ void beacon_send() {
 	}
 	else {
 	    display_status("no beacon text prepared!\n"
-		"You can just select a fixtext containing the [B] key as beacon text,\n"
+		"You can select a fixtext containing the [B] key as beacon,\n"
 		"or you can select a file with <Alt>B.");
+	    beacon_on = 0;
 	    return;
 	}	
 	autorx_on = 1;
@@ -489,11 +517,10 @@ void beacon_send() {
 
 void beacon_stop() {
 	autorx();
-	display_status("Beacon transmission stopped");
-	display_status("after %d transmissions.", beaconcount);
+	display_status("Beacon stopped after %d transmissions.", beaconcount);
 	beaconcount = 0;
 	fixbeacon = 0; 
-	// would resets nr. of fixtext last sent as beacon
+	// resets nr. of fixtext last sent as beacon
 	// so next time beacon is again the first selected file
 	return;				
 }
@@ -767,7 +794,7 @@ void rx_demand_store()
 void usertx() 
 {
 	// user-tx beats (switches off) the autorx() function.
-	display_status("tx on demand -> no auto rx.");
+	// display_status("tx on demand -> no auto rx.");
 	// errprintf((SEV_INFO, "tx on demand -> resetting auto rx and tx");
 	way = TX;
 	beacon_suspend();
@@ -900,6 +927,7 @@ void autotx()
 	msg_send(&msg);
 // 	display_status("autotx(): sending msg for mode %d", fittingtxcmd);
 	lasttxcmd = fittingtxcmd;
+	wait(3000);
 	autorx_on = 1;
 	way = TX;
 	return;
