@@ -240,9 +240,6 @@ create_wspec (void)
   gtk_signal_connect (GTK_OBJECT (spec), "button_press_event",
                       GTK_SIGNAL_FUNC (on_spec_button_press_event),
                       NULL);
-  gtk_signal_connect (GTK_OBJECT (squelch_vruler), "button_press_event",
-                      GTK_SIGNAL_FUNC (on_squelchruler_click_event),
-                      NULL);
   gtk_signal_connect (GTK_OBJECT (spec), "motion_notify_event",
                       GTK_SIGNAL_FUNC (on_spec_motion_event),
                       NULL);
