@@ -40,7 +40,6 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <sys/ioctl.h>
-#include <sys/time.h>
 #include <signal.h>
 #include <sched.h>
 #include <sys/ipc.h>
@@ -52,6 +51,17 @@
 #include <endian.h>
 #endif
 
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
+
 /* --------------------------------------------------------------------- */
 
 #if __BYTE_ORDER == __BIG_ENDIAN
